@@ -1,6 +1,6 @@
 import datetime
 import re
-from typing import Literal, Optional
+from typing import Literal, Optional, Union
 
 import msgspec
 
@@ -24,22 +24,14 @@ class Market(BaseMessage, tag=tag_func):
     exchangeId: str
     marketType: str
     marketStartTime: str
-    numberOfWinners: int | str
+    numberOfWinners: Union[int, str]
 
 
 class Event(BaseMessage, tag=tag_func):
     name: str
     id: str
     countryCode: str
-    children: list[Market]
-
-
-Event = msgspec.defstruct(  # type: ignore
-    "Event",
-    [("name", str), ("id", str), ("countryCode", str), ("children", list[Market | Event])],
-    bases=(BaseMessage,),
-    tag=tag_func,
-)
+    children: list[Union["Group", "Event", Market]]
 
 
 class Race(BaseMessage, tag=tag_func):
@@ -49,31 +41,23 @@ class Race(BaseMessage, tag=tag_func):
     venue: str
     startTime: datetime.datetime
     children: list[Market]
-    raceNumber: str | None = None
+    raceNumber: Optional[str] = None
 
 
 class Group(BaseMessage, tag=tag_func):
     name: str
     id: str
-    children: list[Event | Race]
-
-
-Group = msgspec.defstruct(  # type: ignore
-    "Group",
-    [("name", str), ("id", str), ("children", list[Event | Race | Group])],
-    bases=(BaseMessage,),
-    tag=tag_func,
-)
+    children: list[Union["Group", Event]]
 
 
 class EventType(BaseMessage, tag=tag_func):
     name: str
     id: str
-    children: list[Event | Group | Race]
+    children: list[Union[Group, Event, Race]]
 
 
-class NavigationMarket(BaseMessage):
-    """NavigationMarket"""
+class Navigation(BaseMessage):
+    """Navigation"""
 
     type: Literal["GROUP"]
     name: Literal["ROOT"]
@@ -84,32 +68,31 @@ class NavigationMarket(BaseMessage):
 class FlattenedMarket(BaseMessage, kw_only=True):
     event_type_name: str
     event_type_id: str
-    event_name: str | None = None
-    event_id: str | None = None
-    event_countryCode: str | None = None
+    event_name: Optional[str] = None
+    event_id: Optional[str] = None
+    event_countryCode: Optional[str] = None
     market_name: str
     market_id: str
     market_exchangeId: str
     market_marketType: str
     market_marketStartTime: str
-    market_numberOfWinners: int | str
-    group_name: str | None = None
-    group_id: str | None = None
-    race_name: str | None = None
-    race_id: str | None = None
-    race_countryCode: str | None = None
-    race_venue: str | None = None
-    race_startTime: str | None = None
-    race_raceNumber: str | None = None
+    market_numberOfWinners: Union[int, str]
+    group_name: Optional[str] = None
+    group_id: Optional[str] = None
+    race_name: Optional[str] = None
+    race_id: Optional[str] = None
+    race_countryCode: Optional[str] = None
+    race_venue: Optional[str] = None
+    race_startTime: Optional[str] = None
+    race_raceNumber: Optional[str] = None
 
 
-def flatten_navigation(raw: bytes, **filters) -> list[FlattenedMarket]:
-    data = msgspec.json.decode(raw)
-    flattened = flatten_tree(data, **filters)
+def navigation_to_flatten_markets(navigation: Navigation, **filters) -> list[FlattenedMarket]:
+    flattened = flatten_tree(msgspec.json.decode(msgspec.json.encode(navigation)), **filters)
     return msgspec.json.decode(msgspec.json.encode(flattened), type=list[FlattenedMarket])
 
 
-def flatten_tree(y: dict, **filters):
+def flatten_tree(data: dict, **filters):
     """
     Flatten a nested dict into a list of dicts with each nested level combined
     into a single dict.
@@ -140,5 +123,5 @@ def flatten_tree(y: dict, **filters):
         else:
             yield data
 
-    list(flatten(y))
+    list(flatten(data))
     return results
