@@ -104,7 +104,7 @@ class MarketDefinition(BaseMessage, kw_only=True):
     version: Optional[int] = None
     countryCode: Optional[str] = None
     discountAllowed: Optional[bool] = None
-    raceType: Optional[Literal["Flat"]] = None
+    raceType: Optional[str] = None
     priceLadderDefinition: Optional[Union[str, PriceLadderDescription]] = None
     settledTime: Optional[datetime.datetime] = None
     keyLineDefinition: Optional[KeyLineDefinition] = None
